==> github-app-handler-0.7.2.tar.gz: github-app-handler-0.7.2/README.md <==
# GithubAppHandler
A handler helper to create GitHub App easily

[![Latest Version](https://img.shields.io/github/v/release/heitorpolidoro/github-app-handler?label=Latest%20Version)](https://github.com/heitorpolidoro/github-app-handler/releases/latest)
![GitHub Release Date](https://img.shields.io/github/release-date/heitorpolidoro/github-app-handler)
![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/heitorpolidoro/github-app-handler/latest)
![GitHub last commit](https://img.shields.io/github/last-commit/heitorpolidoro/github-app-handler)
<br>
[![Code Quality](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/code_quality.yml/badge.svg)](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/code_quality.yml)
[![Upload Python Package](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/pypi-publish.yml/badge.svg)](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/pypi-publish.yml)
<br>
[![GitHub issues](https://img.shields.io/github/issues/heitorpolidoro/github-app-handler)](https://github.com/heitorpolidoro/github-app-handler/issues)
![GitHub pull requests](https://img.shields.io/github/issues-pr/heitorpolidoro/github-app-handler)

[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=coverage)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=bugs)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![DeepSource](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler.svg/?label=active+issues&show_trend=true&token=hZuHoQ-gd4kIPgNuSX0X_QT2)](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler/)
[![DeepSource](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler.svg/?label=resolved+issues&show_trend=true&token=hZuHoQ-gd4kIPgNuSX0X_QT2)](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler/)

==> github-app-handler-0.8.tar.gz: github-app-handler-0.8/README.md <==
# GithubAppHandler
A handler helper to create GitHub App easily

[![Code Quality](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/code_quality.yml/badge.svg)](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/code_quality.yml)
[![Upload Python Package](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/pypi-publish.yml/badge.svg)](https://github.com/heitorpolidoro/github-app-handler/actions/workflows/pypi-publish.yml)
<br>
[![Latest Version](https://img.shields.io/github/v/release/heitorpolidoro/github-app-handler?label=Latest%20Version)](https://github.com/heitorpolidoro/github-app-handler/releases/latest)
![GitHub Release Date](https://img.shields.io/github/release-date/heitorpolidoro/github-app-handler)
![GitHub commits since latest release (by SemVer including pre-releases)](https://img.shields.io/github/commits-since/heitorpolidoro/github-app-handler/latest)
![GitHub last commit](https://img.shields.io/github/last-commit/heitorpolidoro/github-app-handler)
<br>
[![GitHub issues](https://img.shields.io/github/issues/heitorpolidoro/github-app-handler)](https://github.com/heitorpolidoro/github-app-handler/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/heitorpolidoro/github-app-handler)](https://github.com/heitorpolidoro/github-app-handler/pulls)

[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=coverage)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=code_smells)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Duplicated Lines (%)](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=duplicated_lines_density)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=vulnerabilities)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=bugs)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=heitorpolidoro_github-app-handler&metric=sqale_index)](https://sonarcloud.io/summary/new_code?id=heitorpolidoro_github-app-handler)
<br>
[![DeepSource](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler.svg/?label=active+issues&show_trend=true&token=hZuHoQ-gd4kIPgNuSX0X_QT2)](https://app.deepsource.com/gh/heitorpolidoro/github-app-handler/)
